bloxone.b1tdlad — Bloxone API Wrapper 0.5.7 documentation

# Source code for bloxone.b1tdlad

    #!/usr/local/bin/python3
    # vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
    '''
    ------------------------------------------------------------------------

     Description:

     BloxOne Threat Defense Enpoint API Wrapper Class and Helpers

     Author: Chris Marrison

     Date Last Updated: 20200818

     Todo:

     Copyright (c) 2018 Chris Marrison / Infoblox

     Redistribution and use in source and binary forms,
     with or without modification, are permitted provided
     that the following conditions are met:

     1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.

     2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.

     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
     "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
     LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
     FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
     COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
     INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
     BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
     CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
     LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
     ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
     POSSIBILITY OF SUCH DAMAGE.

    ------------------------------------------------------------------------
    '''
    __version__ = '0.1.0'
    __author__ = 'Chris Marrison/Krishna Vasudeva'
    __author_email__ = 'chris@infoblox.com'

    import bloxone
    import logging
    import json

    # ** Global Vars **

    class b1tdlad(bloxone.b1):

        # Generic Methods
        def get(self, objpath, **params):
            '''
            Generic get object wrapper for Threat Defense objects

            Parameters:
                objpath (str):  Swagger object path
                id (str):       Optional Object ID
                action (str):   Optional object action, e.g. "nextavailableip"

            Returns:
                response object: Requests response object
            '''
            # Build url
            url = self.tdlad_url + objpath
            url = self._add_params(url, **params)
            logging.debug("URL: {}".format(url))

            response = self._apiget(url)

            return response